<?php
/**
 * Republic functions and definitions
 *
 * @package Republic
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

// Republic's includes directory.
$republic_inc_dir = 'inc';
define( 'REPUBLIC_THEME_DIR', get_template_directory() );
define( 'REPUBLIC_THEME_URI', get_template_directory_uri() );
// Array of files to include.
$republic_includes = array(
	'/theme-settings.php',                  // Initialize theme default settings.
	'/setup.php',                           // Theme setup and custom theme supports.
	'/widgets.php',                         // Register widget area.
	'/enqueue.php',                         // Enqueue scripts and styles.
	'/template-tags.php',                   // Custom template tags for this theme.
	'/pagination.php',                      // Custom pagination for this theme.
	'/hooks.php',                           // Custom hooks.
	'/extras.php',                          // Custom functions that act independently of the theme templates.
	'/customizer.php',                      // Customizer additions.
	'/custom-comments.php',                 // Custom Comments file.
	'/class-wp-bootstrap-navwalker.php',    // Load custom WordPress nav walker.
	'/editor.php',                          // Load Editor functions.
	'/block-editor.php',                    // Load Block Editor functions.
	'/deprecated.php',                      // Load deprecated functions.
	'/widget-popular-posts.php',            // Widget Popular Posts.
	'/widget-latest-posts.php',             // Widget Latest Posts.
	'/widget-block-posts.php',            	// Widget Block Posts.
	'/index-posts.php',             		// Index Posts.
	'/listpostsblock.php',             		// list posts block.
	'/blocks-tiles.php',             		// tiles posts block.
	'/pagemetalayout.php',             		// tiles posts block.
	 '/block-style.php',             		// block-style.
	
);

final class REPUBLIC_Theme_Class {
	public static function republic_constants() {
		
		$version = self::theme_version();

		// Theme version.
		define( 'REPUBLIC_THEME_VERSION', $version );
		
		define( 'REPUBLIC_JS_DIR_URI', REPUBLIC_THEME_URI . '/js/' );
		define( 'REPUBLIC_CSS_DIR_URI', REPUBLIC_THEME_URI . '/css/' );

		// Include Paths.
		define( 'REPUBLIC_INC_DIR', REPUBLIC_THEME_DIR . '/inc/' );
		define( 'REPUBLIC_INC_DIR_URI', REPUBLIC_THEME_URI . '/inc/' );
		
	}
}
new REPUBLIC_Theme_Class();
// Load WooCommerce functions if WooCommerce is activated.
if ( class_exists( 'WooCommerce' ) ) {
	$republic_includes[] = '/woocommerce.php';
}

// Load Jetpack compatibility file if Jetpack is activiated.
if ( class_exists( 'Jetpack' ) ) {
	$republic_includes[] = '/jetpack.php';
}
// Include files.
foreach ( $republic_includes as $file ) {
	require_once get_theme_file_path( $republic_inc_dir . $file );
}

// add the ajax fetch js
add_action( 'wp_footer', 'fetch_ajax' );
function fetch_ajax() {
?>
<script type="text/javascript">
function fetch(){

    jQuery.ajax({
        url: '<?php echo admin_url('admin-ajax.php'); ?>',
        type: 'post',
        data: { action: 'data_fetch', keyword: jQuery('#keyword').val() },
        success: function(data) {
            jQuery('#datafetch').html( data );
        }
    });

}
document.addEventListener('click', function(event) {
    var searchForm = document.getElementById('searchform');
    var searchResult = document.getElementById('datafetch');
    
    // Check if the click is outside the search form or the search result
    if (!searchForm.contains(event.target) && !searchResult.contains(event.target)) {
        searchResult.style.display = 'none'; // Hide the search result if clicked outside
    } else {
        searchResult.style.display = 'block'; // Show the search result if clicked inside
    }
});

// Add event listener to prevent the search result from hiding when clicking inside it
document.getElementById('datafetch').addEventListener('click', function(event) {
    event.stopPropagation(); // Stop the event from propagating to the document click event listener
});
</script>

<?php
}

// the ajax function
add_action('wp_ajax_data_fetch' , 'republic_data_fetch');
add_action('wp_ajax_nopriv_data_fetch','republic_data_fetch');
function republic_data_fetch(){

    $the_query = new WP_Query( array( 'posts_per_page' => -1, 's' => esc_attr( $_POST['keyword'] ), 'post_type' => array('post') ) );
    if( $the_query->have_posts() ) :?>
	<div class="republic-instantsearch">
      <ul>
      <?php while( $the_query->have_posts() ): $the_query->the_post(); ?>
            <li><a href="<?php echo esc_url( get_permalink() ); ?>">
			<?php if (has_post_thumbnail()) : ?>
                        <div class="post-thumbnail">
                            <?php the_post_thumbnail(array(70, 70)); ?>
                        </div>
                    <?php endif; ?><?php the_title();?></a></li>
        <?php endwhile; ?>
     </ul>
	</div>
       <?php wp_reset_postdata();  
    endif;

    die();
}
// Block Theme Support
add_action( 'after_setup_theme', 'republic_block_template_part_support' );
function republic_block_template_part_support() {
	add_theme_support( 'block-template-parts' );
}

function republic_register_pattern_category()
{
	$block_pattern_categories = array(
		'republic' => array('label' => __('republic Patterns', 'republic'))
	);

	$block_pattern_categories = apply_filters('republic_block_pattern_categories', $block_pattern_categories);

	foreach ($block_pattern_categories as $name => $properties) {
		if (!WP_Block_Pattern_Categories_Registry::get_instance()->is_registered($name)) {
			register_block_pattern_category($name, $properties); // phpcs:ignore WPThemeReview.PluginTerritory.ForbiddenFunctions.editor_blocks_register_block_pattern_category
		}
	}
}
add_action('init', 'republic_register_pattern_category', 9);
function republic_primary_menu_fallback() {
  ?>
  
  <ul id="main-menu" class="navbar-nav flex-grow-1 pe-3">
  <li itemscope="itemscope" itemtype="https://www.schema.org/SiteNavigationElement" class="menu-item menu-item-type-post_type menu-item-object-page menu-item-904 nav-item"><a title="Home" href="<?php echo esc_url(get_site_url()); ?>" class="nav-link">Home</a></li>
<li itemscope="itemscope" itemtype="https://www.schema.org/SiteNavigationElement" class="menu-item menu-item-type-custom menu-item-object-custom menu-item-905 nav-item"><a title="Contact us" href="/wp-admin/nav-menus.php" class="nav-link">Set primary menu</a></li>
</ul>
  <?php
}