<?php
/**
 * Republic Theme Customizer
 *
 * @package Republic
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;



if ( ! function_exists( 'republic_customize_register' ) ) {
		
	/**
	 * Register basic support (site title, header text color) for the Theme Customizer.
	 *
	 * @param WP_Customize_Manager $wp_customize Customizer reference.
	 */
	function republic_customize_register( $wp_customize ) {
		$settings = array( 'blogname', 'header_textcolor' );
		foreach ( $settings as $setting ) {
			$get_setting = $wp_customize->get_setting( $setting );
			if ( $get_setting instanceof WP_Customize_Setting ) {
				$get_setting->transport = 'postMessage';
			}
		}

		// Override default partial for custom logo.
		$wp_customize->selective_refresh->add_partial(
			'custom_logo',
			array(
				'settings'            => array( 'custom_logo' ),
				'selector'            => '.custom-logo-link',
				'render_callback'     => 'republic_customize_partial_custom_logo',
				'container_inclusive' => false,
			)
		);
		
		
		
		 class republic_Important_Links extends WP_Customize_Control {

      public $type = "republic-important-links";

      public function render_content() {
      
		 echo '<ul><b>
			<li>' . esc_attr__( '* Fully Mobile Responsive', 'republic' ) . '</li>
			<li>' . esc_attr__( '* Dedicated Option Panel', 'republic' ) . '</li>
			<li>' . esc_attr__( '* Customize Theme Color', 'republic' ) . '</li>
			<li>' . esc_attr__( '* WooCommerce & bbPress Support', 'republic' ) . '</li>
			<li>' . esc_attr__( '* SEO Optimized', 'republic' ) . '</li>
			<li>' . esc_attr__( '* Control Individual Meta Option like: Category, date, Author, Tags etc. ', 'republic' ) . '</li>
			<li>' . esc_attr__( '* Full Support', 'republic' ) . '</li>
			<li>' . esc_attr__( '* Google Fonts', 'republic' ) . '</li>
			<li>' . esc_attr__( '* Theme Color Customization', 'republic' ) . '</li>
			<li>' . esc_attr__( '* Custom CSS', 'republic' ) . '</li>
			<li>' . esc_attr__( '* Website Layout', 'republic' ) . '</li>
			<li>' . esc_attr__( '* Select Number of Columns', 'republic' ) . '</li>
			<li>' . esc_attr__( '* Website Width Control', 'republic' ) . '</li>
			</b></ul>
		 ';
         $important_links = array(
		 
            'theme-info' => array(
               'link' => esc_url('https://www.insertcart.com/product/republic-wordpress-theme/'),
               'text' => __('Republic Pro', 'republic'),
            ),
            'support' => array(
               'link' => esc_url('https://www.insertcart.com/contact-us/'),
               'text' => __('Contact us', 'republic'),
            ),         
			'Documentation' => array(
               'link' => esc_url('https://www.insertcart.com/republic-wordpress-theme-setup-and-documentation/'),
               'text' => __('Documentation', 'republic'),
            ),			 
         );
         foreach ($important_links as $important_link) {
            echo '<p><a target="_blank" href="' . $important_link['link'] . '" >' . esc_attr($important_link['text']) . ' </a></p>';
         }
               }

   }
      $wp_customize->add_section('republic_important_links', array(
      'priority' => 1,
      'title' => __('Upgrade to Pro', 'republic'),
	   ));

	   $wp_customize->add_setting('republic_important_links', array(
		  'capability' => 'edit_theme_options',
		  'sanitize_callback' => 'republic_links_sanitize'
	   ));

	   $wp_customize->add_control(new republic_Important_Links($wp_customize, 'important_links', array(
		  'section' => 'republic_important_links',
		  'settings' => 'republic_important_links'
	   )));	 
		
		
	}
}
add_action( 'customize_register', 'republic_customize_register' );


if ( ! function_exists( 'republic_customize_partial_custom_logo' ) ) {
	/**
	 * Callback for rendering the custom logo, used in the custom_logo partial.
	 *
	 * @return string The custom logo markup or the site title.
	 */
	function republic_customize_partial_custom_logo() {
		if ( has_custom_logo() ) {
			return get_custom_logo();
		} else {
			return get_bloginfo( 'name' );
		}
	}
}


//$dir = REPUBLIC_INC_DIR . 'customizer/controls/';

if ( ! function_exists( 'republic_theme_customize_register' ) ) {
	
	function republic_theme_customize_register( $wp_customize ) {


		class republic_Customizer_Buttonset_Control extends \WP_Customize_Control {
			//public $type = 'text_radio_button';
			
			public function render_content() {
				?>
				<div class="text_radio_button_control">
				<?php if ( ! empty( $this->label ) ) { ?>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<?php } ?>
				<?php if ( ! empty( $this->description ) ) { ?>
					<span class="customize-control-description"><?php echo wp_kses_post( $this->description ); ?></span>
				<?php } ?>				
					<div class="radio-buttons">
						<?php foreach ( $this->choices as $key => $value ) { ?>
							<label class="radio-button-label">
								<input type="radio" name="<?php echo esc_attr( $this->id ); ?>" value="<?php echo esc_attr( $key ); ?>" <?php $this->link(); checked( $this->value(), $key ); ?>/>
								<span><?php echo esc_html( $value ); ?></span>
							</label>
						<?php	} ?>
					</div>
				</div>
				<?php
			}
		}
	

class republic_Image_Radio_Control extends \WP_Customize_Control {
    public function render_content() {
        if (empty($this->choices))
            return;

        $name = '_customize-radio-' . $this->id;
        ?>
        <span class="customize-control-title"><?php echo esc_html($this->label); ?></span>
        <ul class="controls" id='republic-img-container'>
            <?php
            foreach ($this->choices as $value => $label) :
                $class = ($this->value() == $value) ? 'republic-radio-img-selected republic-radio-img-img' : 'republic-radio-img-img';
                ?>
                <li style="display: inline;">
                    <label>
                        <input <?php $this->link(); ?>style = 'display:none' type="radio" value="<?php echo esc_attr($value); ?>" name="<?php echo esc_attr($name); ?>" <?php
                                                      $this->link();
                                                      checked($this->value(), $value);
                                                      ?> />
                        <img src='<?php echo esc_url($label); ?>' class='republic-radio-img republic-radio-img-<?php echo esc_attr($value); ?>' />
                    </label>
                </li>
                <?php
            endforeach;
            ?>
        </ul>
		<script>
            (function ($) {
				
                wp.customize.control('republic_posts_layout', function (control) {
                    control.container.on('change', 'input:radio', function () {
                        var value = $(this).val();
                        control.setting.set(value);

                        // Remove the 'republic-radio-img-selected' class from all images
                        $('ul#republic-img-container img').removeClass('republic-radio-img-selected');
                        // Add the 'republic-radio-img-selected' class to the selected image
                        $('ul#republic-img-container img.republic-radio-img-' + value).addClass('republic-radio-img-selected');
                    });
                });
                wp.customize.control('republic_sidebar_position', function (control) {
                    control.container.on('change', 'input:radio', function () {
                        var value = $(this).val();
                        control.setting.set(value);

                        // Remove the 'republic-radio-img-selected' class from all images
                        $('ul#republic-img-container img').removeClass('republic-radio-img-selected');
                        // Add the 'republic-radio-img-selected' class to the selected image
                        $('ul#republic-img-container img.republic-radio-img-' + value).addClass('republic-radio-img-selected');
                    });
                });
                wp.customize.control('republic_container_type', function (control) {
                    control.container.on('change', 'input:radio', function () {
                        var value = $(this).val();
                        control.setting.set(value);

                        // Remove the 'republic-radio-img-selected' class from all images
                        $('ul#republic-img-container img').removeClass('republic-radio-img-selected');
                        // Add the 'republic-radio-img-selected' class to the selected image
                        $('ul#republic-img-container img.republic-radio-img-' + value).addClass('republic-radio-img-selected');
                    });
                });
                wp.customize.control('republic_header_style', function (control) {
                    control.container.on('change', 'input:radio', function () {
                        var value = $(this).val();
                        control.setting.set(value);

                        // Remove the 'republic-radio-img-selected' class from all images
                        $('ul#republic-img-container img').removeClass('republic-radio-img-selected');
                        // Add the 'republic-radio-img-selected' class to the selected image
                        $('ul#republic-img-container img.republic-radio-img-' + value).addClass('republic-radio-img-selected');
                    });
                });
				
				
            })(jQuery);
        </script>
			<?php
		}
	}
		
	if ( class_exists( 'WP_Customize_Panel' ) ):
	$wp_customize->register_control_type('republic_Customizer_Heading_Control');
	
	$republic_inc_dir = 'inc';
	$republic_includes_controls = array(
		'/controls/class-control-heading.php',               // Heading Controls.
		'/controls/woocommerce.php',                         // WooCommerce Controls.
		'/controls/footerarea.php',                          // Footer Controls.
		'/controls/headercontrol.php',                       // Header Control.
		'/controls/authorcontrol.php',                       // Author Control.
		'/controls/themeelement.php',                        // Theme element Control.
		'/controls/list-block-posts.php',                    // List block posts Control.
		'/controls/news-ticker.php',                         // News Ticker Control.
		'/controls/block-tiles.php',                         // Block Control.
		'/controls/post-settings.php',                         // Block Control.
		'/controls/post-singles.php',                         // Block Control.
		'/controls/sidebars.php',                         // sidebar
		'/controls/breadcrumbs.php',                         // Breadcrumbs
		'/controls/404errorcontrol.php',                         // 404 error
	);
	// Include files.
	foreach ( $republic_includes_controls as $file ) {
		require_once get_theme_file_path( $republic_inc_dir . $file );
	}
	
	$wp_customize->get_section( 'background_image' )->panel = 'panel_general';
	 $wp_customize->get_section( 'colors' )->panel = 'panel_general';
	
	$colors_section = $wp_customize->get_section( 'colors' );
    // Check if the section exists
    if ( $colors_section ) {
        // Set a new title for the colors section
        $colors_section->title = __( 'Theme Background Color', 'republic' );
    }
	$wp_customize->add_panel( 'panel_general', array(
			'priority' => 30,
			'capability' => 'edit_theme_options',
			'description' => __( 'Control theme default settings', 'republic' ),
			'priority'    => apply_filters( 'republic_theme_settings_priority', 150 ),
			'title' => __( 'Theme Settings', 'republic' )
		) );
	/*********************
	Browser Color
	*******************/
	$wp_customize->add_setting(
		'republic_browser_color', array(
		'default' => '#03A9F4', // Default font color
		'sanitize_callback' => 'sanitize_hex_color',
	));

	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'republic_browser_color', array(
		'label' => __('Default Browser Color (Effect only Mobile)', 'republic'),
		'section' => 'colors',
		'settings' => 'republic_browser_color',
	)));		
		
		$wp_customize->add_section('custom_section_css',
				array(
					'title'			=> __( 'Custom CSS', 'republic' ),			
					'panel'			=> 'panel_general',
					'priority'    => 32
				)
			);
        $wp_customize->add_setting('custom_css',
		array(
			'default'			=> '',
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'    => 'wp_filter_nohtml_kses',
			'sanitize_js_callback' => 'wp_filter_nohtml_kses'
		)
	);
       $wp_customize->add_control('custom_css',
		array(

			'settings'		=> 'custom_css',
			'section'		=> 'custom_section_css',
			'type'			=> 'textarea',
			'label'			=> __( 'Custom CSS', 'republic' ),
			'description'	=> __( 'Define custom CSS be used for your site. Do not enclose in script tags.', 'republic' ),
		)
	);
	
		/*********************
		Menu settings. Style One
		*******************/
		$wp_customize->add_section(
			'republic_menu_settings',
			array(
				'title'       => __( 'Menu Settings', 'republic' ),
				'description'       => __( 'Menu Settings', 'republic' ),
				'capability'  => 'edit_theme_options',						
				'panel'			=> 'panel_general',
			)
		);
		
		$wp_customize->add_setting('republic_topside',	
			array(
				'default'			=> 'enable',
				'type'				=> 'theme_mod',
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'republic_customize_sanitize_select'
			));
		$wp_customize->add_control('republic_topside',
			 array (                             
				'type' => 'radio',
				'label' => __('Enable Woocommerce/Search Bar in Right','republic'),
				'settings'   => 'republic_topside',
				'section' => 'republic_theme_settings',
				'choices' => array(
					'enable' => __('Enable','republic'),
					'disable' => __('Disable','republic'),
				 ),
			 ));		

		
		/*********************
		Social Links
		*******************/
		$wp_customize->add_section('republic_sociallinks',
			array(
				'title'       => __( 'Social Links', 'republic' ),
				'description'       => __( 'Author Profile Control on Posts and Archive Pages (Make Sure to fill all detail to show profile in Dashboard > Users > Profile)', 'republic' ),
				'capability'  => 'edit_theme_options',						
				'panel'			=> 'republic_theme_elements',
			));
			
		// Add setting for social media links style
    $wp_customize->add_setting('social_links_style', array(
        'default' => 'rounded-circle',
        'sanitize_callback' => 'sanitize_text_field',
    ));

    // Add control for social media links style
    $wp_customize->add_control('social_links_style', array(
        'label' => __('Social Links Style', 'republic'),
        'section' => 'republic_sociallinks',
        'type' => 'select',
        'choices' => array(
            'rounded' => __('Round', 'republic'),
            'rounded-circle' => __('Circle', 'republic'),
            'rounded-0' => __('Tile', 'republic'),
        ),
    ));	
	$social_media_platforms = array(
        'facebook' => __('Facebook', 'republic'),
        'twitter' => __('Twitter', 'republic'),
        'whatsapp' => __('WhatsApp', 'republic'),
        'calling' => __('Calling', 'republic'),
        'youtube' => __('YouTube', 'republic'),
    );

    foreach ($social_media_platforms as $platform => $label) {
        $wp_customize->add_setting("social_media_$platform", array(
            'default' => '',
            'sanitize_callback' => 'esc_url_raw',
        ));

        $wp_customize->add_control("social_media_$platform", array(
            'label' => $label . ' URL',
            'section' => 'republic_sociallinks',
            'type' => 'text',
        ));
    }
		
		/*********************
		Google Fonts
		*******************/
		$wp_customize->add_section('republic_google_font',
			array(
				'title'       => __( 'Google Fonts', 'republic' ),
				'description'       => __( 'Google Fonts Settings', 'republic' ),
				'capability'  => 'edit_theme_options',						
				'panel'			=> 'panel_general',
			)
		);
		$font_array = array('Raleway','Khula','Open Sans','Poppins','Futura','Indie Flower','Droid Sans','Droid Serif','Roboto','Roboto Condensed','Lato','Bree Serif','Oswald','Slabo','Lora','Source Sans Pro','PT Sans','Ubuntu','Lobster','Arimo','Bitter','Noto Sans','Fjalla One','PT Sans Narrow','Poiret One','Passion One','Arvo','Inconsolata','Shadows Into Light','Pacifico','Dancing Script','Architects Daughter','Sigmar One','Righteous','Amatic SC','Orbitron','Chewy','Lobster Two','Gloria Hallelujah','Lekton','Almendra Display','Swanky and Moo Moo','Hanalei Fill','Uncial Antiqua','Rouge Script','Engagement','Bonbon','Caesar Dressing','Kenia','Lemon','Stardos Stencil','Bilbo','Macondo','Delius Unicase','Butcherman','Monoton','Nosifer','Codystar','Fontdiner Swanky','Diplomata SC','Snowburst One','Faster One','Rock Salt','Eater','Noto Sans JP','Montserrat','Fira Sans','Baloo Tamma 2','AR One Sans','Alegreya','Anek Kannada','Anek Odia','Anek Tamil','Anek Devanagari');
		$fonts = array_combine($font_array, $font_array);

		$wp_customize->add_setting('republic_enablefonts',	
			array(
				'default'			=> 'disable',
				'type'				=> 'theme_mod',
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'republic_customize_sanitize_select'
			));
		$wp_customize->add_control('republic_enablefonts',
			 array (                             
				'type' => 'radio',
				'label' => __('Enable Google Fonts','republic'),
				'settings'   => 'republic_enablefonts',
				'section' => 'republic_google_font',
				'choices' => array(
					'enable' => __('Enable','republic'),
					'disable' => __('Disable','republic'),
				 ),
			 ));
		
	
		$wp_customize->add_setting(
		'republic_body_font',
			array(	
			'default'=> 'Open Sans',
			'sanitize_callback' => 'republic_sanitize_gfont' 
		));

		$wp_customize->add_control(
			'republic_body_font',array(
					'label' => __('Body Font Family','republic'),
					'settings' => 'republic_body_font',
					'section'  => 'republic_google_font',
					'type' => 'select',
					'choices' => $fonts
			));
		
	

		
		/*********************
		Theme settings.
		*******************/
		$wp_customize->add_section(
			'republic_theme_settings',
			array(
				'title'       => __( 'Preloading Bar', 'republic' ),
				'capability'  => 'edit_theme_options',
				'description' => __( 'Effects while loading your website', 'republic' ),							
				'panel'			=> 'panel_general',
			));			
		
			
			$wp_customize->add_setting('republic_loading_animation',	
			array(
				'default'			=> 'enable',
				'type'				=> 'theme_mod',
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'republic_customize_sanitize_select'
			));
		$wp_customize->add_control('republic_loading_animation',
			 array (                             
				'type' => 'radio',
				'label' => __('Enable Loading Animation','republic'),
				'settings'   => 'republic_loading_animation',
				'section' => 'republic_theme_settings',
				'choices' => array(
					'enable' => __('Enable','republic'),
					'disable' => __('Disable','republic'),
				 ),
			 ));

			// Add a control to choose the loading bar color
			$wp_customize->add_setting('republic_loading_bar_color', array(
				'default' => '#ff3030',
				'transport' => 'refresh',
				'sanitize_callback'	=> 'sanitize_hex_color',
			));

			$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'republic_loading_bar_color', array(
				'label' => __('Loading Bar Color', 'republic'),
				'section' => 'republic_theme_settings',
			)));


			$wp_customize->add_section(
				'republic_scrolltop_section',
				array(
					'title'       => __( 'Scroll To Top', 'republic' ),
					'capability'  => 'edit_theme_options',						
					'panel'			=> 'panel_general',
				));

			
			//back to top
		$wp_customize->add_setting('republic_backtotop',	
			array(
				'default'			=> 'enable',
				'type'				=> 'theme_mod',
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'republic_customize_sanitize_select'
			));
		$wp_customize->add_control('republic_backtotop',
			 array (                             
				'type' => 'radio',
				'label' => __('Scroll to Top Button Control','republic'),
				'settings'   => 'republic_backtotop',
				'section' => 'republic_scrolltop_section',
				'choices' => array(
					'enable' => __('Enable','republic'),
					'disable' => __('Disable','republic'),
				 ),
			 ));
		$wp_customize->add_setting( 'republic_backtotop_bg' , array(
			'default'     => '#E53B2C',
			'transport'   => 'refresh',
			'sanitize_callback'	=> 'sanitize_hex_color',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'republic_backtotop_bg', array(
		'description'        => __( 'Background Color', 'republic' ),
		'section'    => 'republic_scrolltop_section',
		'settings'   => 'republic_backtotop_bg',
		) ) );
		$wp_customize->add_setting( 'republic_backtotop_bghover' , array(
			'default'     => '#9E9E9E',
			'transport'   => 'refresh',
			'sanitize_callback'	=> 'sanitize_hex_color',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'republic_backtotop_bghover', array(
		'description'        => __( 'Background Hover Color', 'republic' ),
		'section'    => 'republic_scrolltop_section',
		'settings'   => 'republic_backtotop_bghover',
		) ) );
		$wp_customize->add_setting( 'republic_backtotop_text' , array(
			'default'     => '#ffffff',
			'transport'   => 'refresh',
			'sanitize_callback'	=> 'sanitize_hex_color',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'republic_backtotop_text', array(
		'description'        => __( 'Icon Color', 'republic' ),
		'section'    => 'republic_scrolltop_section',
		'settings'   => 'republic_backtotop_text',
		) ) );
		$wp_customize->add_setting( 'republic_backtotop_texthover' , array(
			'default'     => '#333333',
			'transport'   => 'refresh',
			'sanitize_callback'	=> 'sanitize_hex_color',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'republic_backtotop_texthover', array(
		'description'        => __( 'Icon Hover Color', 'republic' ),
		'section'    => 'republic_scrolltop_section',
		'settings'   => 'republic_backtotop_texthover',
		) ) );


			$wp_customize->add_setting(
				'republic_scroll_top_position',
				array(
					'transport'         => 'postMessage',
					'default'           => 'right',
					'sanitize_callback' => 'republic_customize_sanitize_select',
				)
			);

			$wp_customize->add_control(
				new republic_Customizer_Buttonset_Control(
					$wp_customize,
					'republic_scroll_top_position',
					array(
						'label'           => esc_html__( 'Scroll Button Position', 'republic' ),
						'section'         => 'republic_scrolltop_section',
						'settings'        => 'republic_scroll_top_position',
						'priority'        => 10,
						'choices'         => array(
							'left'  => esc_html__( 'Left', 'republic' ),
							'right' => esc_html__( 'Right', 'republic' ),
						),
					)
				)
			);
			$wp_customize->add_setting('republic_scrolltop_radius', array(
				'default'           => 5,
				'transport'         => 'postMessage',
				'sanitize_callback' => 'absint', // Sanitize as integer
			));
	
			$wp_customize->add_control('republic_scrolltop_radius', array(
				'type'        => 'range',
				'section'     => 'republic_scrolltop_section',
				'settings'    => 'republic_scrolltop_radius',
				'description' => __('Button Radius', 'republic'),
				'priority' => 20,
				'input_attrs' => array(
					'min'  => 1,
					'max'  => 100,
					'step' => 5,
				),
			));	

//Woocommerce Sidebar
		$wp_customize->add_section('republic_woosidebars_section',
        array(
            'title' => __( 'Sidebar', 'republic' ),
            'description' => __( 'Sidebar Panel', 'republic' ),
            'capability'  => 'edit_theme_options',		
            'panel'			=> 'woocommerce',
            'priority'    => apply_filters( 'republic_sidebars_section_priority', 10 ),
        ));
        $wp_customize->add_setting('republic_woo_sides',	
        array(
            'default'			=> 'disable',
            'type'				=> 'theme_mod',
            'capability'		=> 'edit_theme_options',
            'sanitize_callback'	=> 'republic_customize_sanitize_select'
        ));
        $wp_customize->add_control('republic_woo_sides',
            array (                             
            'type' => 'radio',
            'label' => __('WooCommerce Sidebars','republic'),
            'settings'   => 'republic_woo_sides',
            'section' => 'republic_woosidebars_section',
            'choices' => array(
                'enable' => __('Enable','republic'),
                'disable' => __('Disable','republic'),
                ),
            ));
			 
		
		
endif;
	
	 
			 
			
// Theme layout settings.
		$wp_customize->add_section(
			'republic_theme_layout_options',
			array(
				'title'       => __( 'Theme Layout Settings', 'republic' ),
				'capability'  => 'edit_theme_options',
				'description' => __( 'Container width and sidebar defaults', 'republic' ),
				'priority'    => apply_filters( 'republic_theme_layout_options_priority', 160 ),
			)
		);

		$wp_customize->add_setting(
			'republic_container_type',
			array(
				'default'           => 'container',
				'type'              => 'theme_mod',
				'sanitize_callback' => 'republic_customize_sanitize_select',
				'capability'        => 'edit_theme_options',
			)
		);
		
		
		$wp_customize->add_control(
			new republic_Image_Radio_Control(
				$wp_customize,
				'republic_container_type',
				array(
					'label'       => __( 'Container Width', 'republic' ),
					'description' => __( 'Choose between Fixed or Full width container', 'republic' ),
					'section'     => 'republic_theme_layout_options',
					'choices'     => array(
						'container-fluid'  => get_template_directory_uri() . '/images/widthfull.png',
						'container' => get_template_directory_uri() . '/images/widthfixed.png',
						'container-box' => get_template_directory_uri() . '/images/widthbox.png',
					),
					'priority'    => apply_filters( 'republic_container_type_priority', 10 ),
				)
			));

		$wp_customize->add_setting(
			'republic_content_background',
			array(
				'default'           => 'contentdefault',
				'type'              => 'theme_mod',
				'sanitize_callback' => 'republic_customize_sanitize_select',
				'capability'        => 'edit_theme_options',
			)
		);
		
		
		$wp_customize->add_control(
			new republic_Image_Radio_Control(
				$wp_customize,
				'republic_content_background',
				array(
					'label'       => __( 'Content Background (Blended / Separated )', 'republic' ),
					'description' => __( 'Choose website content Full background or Content only', 'republic' ),
					'section'     => 'republic_theme_layout_options',
					'choices'     => array(
						'contentdefault'  => get_template_directory_uri() . '/images/c.png',
						'contentblock' => get_template_directory_uri() . '/images/contentblock.png',
					),
					'priority'    => apply_filters( 'republic_container_type_priority', 30 ),
				)
			));

	/* 	$wp_customize->add_control(
			new WP_Customize_Control(
				$wp_customize,
				'republic_container_type',
				array(
					'label'       => __( 'Container Width', 'republic' ),
					'description' => __( 'Choose between Fixed or Full width container', 'republic' ),
					'section'     => 'republic_theme_layout_options',
					'type'        => 'select',
					'choices'     => array(
						'container'       => __( 'Fixed width container', 'republic' ),
						'container-fluid' => __( 'Full width container', 'republic' ),
						'container-box' => __( 'Box', 'republic' ),
					),
					'priority'    => apply_filters( 'republic_container_type_priority', 10 ),
				)
			)
		); */
	
		

		$republic_site_info = $wp_customize->get_setting( 'republic_site_info_override' );
		if ( $republic_site_info instanceof WP_Customize_Setting ) {
			$republic_site_info->transport = 'postMessage';
		}
		
		
	}

	
	
} // End of if function_exists( 'republic_theme_customize_register' ).
add_action( 'customize_register', 'republic_theme_customize_register' );




if ( ! function_exists( 'republic_customize_sanitize_select' ) ) {
	function republic_customize_sanitize_select( $input, $setting ) {

		// Ensure input is a slug (lowercase alphanumeric characters, dashes and underscores are allowed only).
		$input = sanitize_key( $input );

		$control = $setting->manager->get_control( $setting->id );
		if ( ! $control instanceof WP_Customize_Control ) {
			return false;
		}

		// Get the list of possible select options.
		$choices = $control->choices;

		// If the input is a valid key, return it; otherwise, return the default.
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
	}
}



/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
 
 function republic_customize_preview_js() {
	$file = '/js/customizer.js';
	$files = '/js/customizer-controls.js';

	$url = get_template_directory_uri() . $file;
	$urls = get_template_directory_uri() . $files;
	$version = filemtime( get_template_directory() . $file );
	if ( false === $version ) {
		$version = time();
	}

	wp_enqueue_script(
		'republic_customizer_result',
		$url,
		array( 'customize-preview' ),
		(string) $version,
		true
	);
	wp_enqueue_script( 'republic-customizer-preview', $urls , array( 'customize-preview', 'jquery' ) );
}
add_action( 'customize_preview_init', 'republic_customize_preview_js' );



function republic_is_post_meta_enabled($control) {
	return get_theme_mod('republic_blog_postmeta', 'enable') === 'enable';
}

function republic_header_selected_styleone($control) {
    return get_theme_mod('republic_header_style', 'styleone') === 'styleone';
}

function republic_header_selected_styletwo($control) {
    return get_theme_mod('republic_header_style', 'styletwo') === 'styletwo';
}

function republic_header_selected_stylethree($control) {
    return get_theme_mod('republic_header_style', 'stylethree') === 'stylethree';
}
function republic_is_readmore_enabled($control) {
	return get_theme_mod('republic_enable_readmore', 'enable') === 'enable';
}

function republic_sanitize_gfont( $input ) {
		if ( in_array($input, array('Raleway','Khula','Open Sans','Poppins','Futura','Indie Flower','Droid Sans','Droid Serif','Roboto','Roboto Condensed','Lato','Bree Serif','Oswald','Slabo','Lora','Source Sans Pro','PT Sans','Ubuntu','Lobster','Arimo','Bitter','Noto Sans','Fjalla One','PT Sans Narrow','Poiret One','Passion One','Arvo','Inconsolata','Shadows Into Light','Pacifico','Dancing Script','Architects Daughter','Sigmar One','Righteous','Amatic SC','Orbitron','Chewy','Lobster Two','Gloria Hallelujah','Lekton','Almendra Display','Swanky and Moo Moo','Hanalei Fill','Uncial Antiqua','Rouge Script','Engagement','Bonbon','Caesar Dressing','Kenia','Lemon','Stardos Stencil','Bilbo','Macondo','Delius Unicase','Butcherman','Monoton','Nosifer','Codystar','Fontdiner Swanky','Diplomata SC','Snowburst One','Faster One','Rock Salt','Eater','Noto Sans JP','Montserrat','Fira Sans','Baloo Tamma 2','AR One Sans','Alegreya','Anek Kannada','Anek Odia','Anek Tamil','Anek Devanagari') ) )
			return $input;
		else
			return '';	
	}
	
if ( ! function_exists( 'republic_headerone' ) ) {
	function republic_headerone( $current_mod ) {

		if ( 'styletwo' !== get_theme_mod( 'republic_header_style' ) ) {
			$current_mod = 'enable';
		}

		return $current_mod;
	}
}
add_filter( 'theme_mod_republic_heroarea', 'republic_headerone', 30 );	
	