<?php
/**
 * Republic enqueue scripts
 *
 * @package Republic
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

if ( ! function_exists( 'republic_scripts' ) ) {
	/**
	 * Load theme's JavaScript and CSS sources.
	 */
	function republic_scripts() {
		// Get the theme data.
		$the_theme         = wp_get_theme();
		$theme_version     = $the_theme->get( 'Version' );	
		$suffix            = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		// Grab asset urls.
		$theme_styles  = "/css/theme.css";
		$theme_styles_bootstraputiliti  = "/css/bootstrap-utilities.min.css";
		//$theme_styles  = "/css/theme{$suffix}.css";
		$theme_scripts = "/js/theme{$suffix}.js";

		$css_version = $theme_version . '.' . filemtime( get_template_directory() . $theme_styles ); // @phpstan-ignore-line -- file exists
		wp_enqueue_style( 'republic-styles', get_template_directory_uri() . $theme_styles, array(), $css_version );
		wp_enqueue_style( 'republic-styles-bootstrap-utilities', get_template_directory_uri() . $theme_styles_bootstraputiliti, array(), $css_version );
		republic_offcanvas_admin_bar_inline_styles();
		republic_settings_css();
		if(get_theme_mod( 'republic_container_type' ) == 'container-box'){republic_boxcss();}
		if(get_theme_mod( 'republic_content_background' ) == 'contentblock'){republic_contentblock();}
		if (get_theme_mod('republic_heroarea') =='enable')	{republic_header_styletwo();}
		if (get_theme_mod('republic_thumbhover') =='enable')	{republic_thumbhover();}
		if (get_theme_mod('republic_woostyle') !=='disable')	{republic_woostyle();}
		
		wp_enqueue_script( 'jquery' );

		wp_enqueue_script('ajax-search', get_template_directory_uri() . '/js/ajax-search.js', array('jquery'), '1.0', true);
		wp_localize_script('ajax-search', 'ajaxsearch', array('ajaxurl' => admin_url('admin-ajax.php')));
	

		$js_version = $theme_version . '.' . filemtime( get_template_directory() . $theme_scripts ); // @phpstan-ignore-line -- file exists
		wp_enqueue_script( 'republic-scripts', get_template_directory_uri() . $theme_scripts, array(), $js_version, true );
		wp_enqueue_script('republic-ticker-js', get_template_directory_uri().'/js/tickerme.js', array(), '1.0', false );
		
		republic_scrolltop();
		if (get_theme_mod('republic_loading_animation') !== 'disable' ){ repulicpro_js_codes(); }
		if (get_theme_mod('republic_stickymenu') == 'sticky-top' ){ repulicpro_ifstickytop(); }
		
		wp_enqueue_script('republic-tickertwo-js', get_template_directory_uri().'/js/jquery.ticker.js', array(), '1.0', false );	

		if (get_theme_mod('republic_enablefonts') == 'enable' ){
		wp_enqueue_style('republic-body-font', '//fonts.googleapis.com/css?family='.str_replace(" ", "+", get_theme_mod('republic_body_font', 'Open Sans') ).':100,300,400,500,600,700' );
		}
		
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
	}
} // End of if function_exists( 'republic_scripts' ).

add_action( 'wp_enqueue_scripts', 'republic_scripts' );

/**
* Enqueue script for custom customize control.
*/
function republic_custom_customize_enqueue() {
	wp_enqueue_style( 'customizer-css', get_stylesheet_directory_uri() . '/css/customizer-css.css' );
}
add_action( 'customize_controls_enqueue_scripts', 'republic_custom_customize_enqueue' );


if ( ! function_exists( 'republic_offcanvas_admin_bar_inline_styles' ) ) {
	/**
	 * Add inline styles for the offcanvas component if the admin bar is visibile.
	 *
	 * Fixes that the offcanvas close icon is hidden behind the admin bar.
	 *
	 * @since 1.2.0
	 */
	function republic_offcanvas_admin_bar_inline_styles() {
		$navbar_type = get_theme_mod( 'republic_navbar_type', 'collapse' );
		if ( 'offcanvas' !== $navbar_type ) {
			return;
		}
		$css = '
		body.admin-bar .offcanvas.show  {
			margin-top: 32px;
		}
		@media screen and ( max-width: 782px ) {
			body.admin-bar .offcanvas.show {
				margin-top: 46px;
			}
		}';
		wp_add_inline_style( 'republic-styles', $css );
	}
}
$loadcbar = ''; // Initialize $loadcbar with an empty string
if ( ! function_exists( 'republic_settings_css' ) ) {
	
	if (get_theme_mod('republic_loading_animation') !== 'disable' ){
		$loadcbar = '@keyframes page-load{from{width:0}to{width:100%}}.page-loading::before{content:" ";display:block;position:fixed;z-index:10;height:3px;width:100%;top:0;left:0;background-color:#ff3030;animation:page-load ease-out 2s}.page-loading #wpadminbar{margin-top: 3px;}';}

		
	function republic_settings_css(){	
		
		 global $loadcbar, $heroarea;
		 $custom_csscode = get_theme_mod('custom_css', '');
		 $morefonts  = 'system-ui,
  -apple-system, "Segoe UI", Roboto, "Helvetica Neue", "Noto Sans", "Liberation Sans", Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji"';
		$custom_css = 'body{font-family: '.esc_html(get_theme_mod('republic_body_font')).','.$morefonts.';} .row.post-footer a.read-more-link{color: '.esc_html(get_theme_mod('republic_readmore_color','#0d6efd')).' !important;}
		.styleone-header nav#main-nav{background: linear-gradient(0deg, '.esc_html(get_theme_mod('republic_primarymenubg','#485561')).' 50%, '.esc_html(get_theme_mod('republic_primarymenubgs','#56636f')).' 50%) !important;}
		.styleone-header .republicprimaryone ul#main-menu li a:hover{background-color: '.esc_html(get_theme_mod('republic_primarymenuhover','#f3f3f3')).' !important;color: '.esc_html(get_theme_mod('republic_primarymenuhovertext','#333333')).' !important;}
		div#wrapper-navbar .nav-link{color: '.esc_html(get_theme_mod('republic_primarymenutext','#ffffff')).' !important;}
		.stylethree-header div#wrapper-navbar .nav-link{color: '.esc_html(get_theme_mod('republic_primarymenutext_three','#2f2b2b')).' !important;}
		.stylethree-header div#wrapper-navbar .nav-link:hover{color: '.esc_html(get_theme_mod('republic_primarymenutexthover_three','#3d951e')).' !important;}
		#wrapper-footer-full, #wrapper-static-hero{background-color: '.esc_html(get_theme_mod('republic_footerbg','#e9ecef')).';}
		.stylethree-header #wrapper-navbar nav#main-nav{background-color: '.esc_html(get_theme_mod('republic_primarymenubg_three','#ffffff')).' !important;}
		div#blockbig h3.entry-title a,#blocksmall h3.entry-title a{color: '.esc_html(get_theme_mod('republic_blogtileslink','#ffffff')).' !important;}
		.container span.categoryblock a{background-color: '.esc_html(get_theme_mod('republic_blogtilescatbg','#673AB7')).' !important;color: '.esc_html(get_theme_mod('republic_blogtilescatfont','#ffffff')).' !important;}

		div#wrapper-footer{background: '.esc_html(get_theme_mod('republic_footer_copy','#494949')).';}
		.styletwo-header a.nav-link{color: '.esc_html(get_theme_mod('republic_heroarea_links','#343434')).' !important;}
		.styletwo-header ul#main-menu li a:hover{color: '.esc_html(get_theme_mod('republic_heroarea_links_hover','#FF9800')).' !important;}
		header#wrapper-navbar.topbarthree{color: '.esc_html(get_theme_mod('republic_topnavibg_three','#3e4451')).' !important; color: '.esc_html(get_theme_mod('republic_topnavitext_three','#e0e0e0')).' !important;}
		.scrollup:hover{background-color: '.esc_html(get_theme_mod('republic_backtotop_bghover','#9E9E9E')).' !important;color: '.esc_html(get_theme_mod('republic_backtotop_texthover','#333333')).' !important;}	
		.scrollup{background-color: '.esc_html(get_theme_mod('republic_backtotop_bg','#E53B2C')).' !important;border-radius: '.esc_html(get_theme_mod('republic_scrolltop_radius','5')).'px;color: '.esc_html(get_theme_mod('republic_backtotop_text','#ffffff')).' !important;}		'. $loadcbar . '
		h2.entry-title a{color: '.esc_html(get_theme_mod('republic_posttitlefont_color','#333333')).' !important;font-size: '.esc_html(get_theme_mod('republic_posttitlefont','20')).'px !important; font-style: '.esc_html(get_theme_mod('republic_posttitlefont_style','normal')).' !important;text-transform: '.esc_html(get_theme_mod('republic_posttitlefont_transform','none')).' !important;font-weight: '.esc_html(get_theme_mod('republic_posttitlefont_weight','600')).' !important;}
		.post-excerpt p{color: '.esc_html(get_theme_mod('republic_postexcert_color','#5e5d5d')).' !important;font-size: '.esc_html(get_theme_mod('republic_postexcert_size','17')).'px !important; font-style: '.esc_html(get_theme_mod('republic_postexcert_style','normal')).' !important;text-transform: '.esc_html(get_theme_mod('republic_postexcert_transform','none')).' !important;font-weight: '.esc_html(get_theme_mod('republic_postexcert_weight','100')).' !important;}h1.entry-title{color: '.esc_html(get_theme_mod('republic_postsingle_color','#333333')).' !important;font-size: '.esc_html(get_theme_mod('republic_postsingle_size','32')).'px !important; font-style: '.esc_html(get_theme_mod('republic_postsingle_style','normal')).' !important;text-transform: '.esc_html(get_theme_mod('republic_postsingle_transform','none')).' !important;font-weight: '.esc_html(get_theme_mod('republic_postsingle_weight','100')).' !important;}
		.page-loading::before {background-color: '.esc_html(get_theme_mod('republic_loading_bar_color','#ff3030')).' !important;} '.$custom_csscode.'	
			
		';		
		wp_add_inline_style( 'republic-styles', $custom_css );
	}
}

if ( ! function_exists( 'repulicpro_js_codes' ) ) {
	
	function repulicpro_js_codes(){
		
		$jscode = '(function( $ ) {
		  $(document).ready(function() {
				// Attach event listeners to specific links or elements where you want to trigger the loading animation
				var linksToAnimate = document.querySelectorAll(".load-animation-link");
				linksToAnimate.forEach(function(link) {
					link.addEventListener("click", function(e) {
						e.preventDefault(); // Prevent the default link behavior
						document.body.classList.add("page-loading");
						// Remove the loading class when the content has loaded
						window.addEventListener("DOMContentLoaded", function() {
							document.body.classList.remove("page-loading");
						});
					});
				});
				// Use this if you still want the loading animation on beforeunload
				window.addEventListener("beforeunload", function() {
					document.body.classList.add("page-loading");
				});
				
				$("#ticker").tickerme();
				 $("#js-news").ticker();
				
			});
		})(jQuery);';
		wp_add_inline_script( 'republic-scripts', $jscode );		
	}
}

function republic_admin_enqueue_styles() {
    wp_enqueue_style('republic-admin-css', get_template_directory_uri() . '/css/admin-style.css');
}
add_action('admin_enqueue_scripts', 'republic_admin_enqueue_styles');



 function republic_boxcss(){
    $mycss='body {max-width: 1279px;margin: 0 auto;background: #ececec;	}
	div#page {background: #ffffff;box-shadow: 10px 0 10px -10px #bbb, -10px 0 10px -10px #bbb;}
	';
   wp_add_inline_style( 'republic-styles', $mycss );
} 
 function republic_thumbhover(){
    $thumbhover='article .col-auto.d-lg-block:hover img {
    -webkit-transform: scale(1.1, 1.1);-moz-transform: scale(1.1, 1.1);-o-transform: scale(1.1, 1.1);-ms-transform:scale(1.1, 1.1);transform: scale(1.1, 1.1);-webkit-transition: all 0.6s linear;-moz-transition: all 0.6s linear;-o-transition: all 0.6s linear;-ms-transition: all 0.6s linear;transition: all 0.6s linear;}';
   wp_add_inline_style( 'republic-styles', $thumbhover );
} 
 function republic_contentblock(){
    $republic_contentblock='
	div#page {background: transparent !important;box-shadow: none !important;}
	.woocommerce ul.products li.product .woocommerce-loop-product__title,.woocommerce ul.products li.product .price,.card .add-to-cart-container {padding: 10px;}
	.woocommerce ul.products li.product a img{border-top-left-radius: 0.375rem;border-top-right-radius: 0.375rem;}
	.woocommerce ul.products li.product, .woocommerce-page ul.products li.product,
	article .row.g-0.border.rounded.overflow-hidden.flex-md-row.mb-4.shadow-sm.position-relative {background: #ffffff;}
	.republic-indexwid .col-md-7 ul li,
	.republic-indexwid .col-md-5,
	body.single-post main#main,
	body.page main#main,
	body.single-product main#main{background: #fff;padding: 2%;}
	.republic-popular, .republic-latest,div#left-sidebar aside, div#right-sidebar aside{padding: 10px;background: #ffffff;margin: 8px 0px;}
	div#left-sidebar aside:first-child,	div#right-sidebar aside:first-child{margin-top:0px;}';
   wp_add_inline_style( 'republic-styles', $republic_contentblock );
} 

function republic_header_styletwo(){
	$heroarea = '.styletwo-header nav#main-nav{background: #00000014 !important;}header#wrapper-navbar.nonfixed {height: 0;z-index: 100;position: relative;}';
	wp_add_inline_style( 'republic-styles', $heroarea );
}

function republic_woostyle(){
	$woostyle = '';
	wp_add_inline_style( 'republic-styles', $woostyle );
}

function republic_scrolltop(){	
	if(get_theme_mod('republic_scroll_top_position')=='left'){
		$scrollcss = '.scrollup{left: 0;right:  auto ;}';
	}
	else if(get_theme_mod('republic_scroll_top_position')=='right'){
		$scrollcss = '.scrollup{left: auto;right:  0;}';
	}
	else{
		$scrollcss = '.scrollup{left: auto;right:  0;}';
	}

	wp_add_inline_style( 'republic-styles', $scrollcss );
}

function repulicpro_ifstickytop(){
	$ifstickytop = '#wpadminbar + .styletwo-header>.container{margin-top: 120px;}header#wrapper-navbar.sticky-top{height:0;} #wpadminbar + .styletwo-header header#wrapper-navbar{margin-top: 32px;}#customize-preview .styletwo-header>.container{margin-top: 120px;}';
	wp_add_inline_style( 'republic-styles', $ifstickytop );
}
