<?php
/**
 * Republic enqueue scripts
 *
 * @package Republic
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;
function republic_add_page_layout_meta_box( $post ){
    add_meta_box( 'republic_page_meta', __( '<span class="dashicons dashicons-layout"></span> Page Layout', 'republic' ), 'republic_build_page_layout_meta_box', 'page', 'side', 'high' );
}
add_action( 'add_meta_boxes', 'republic_add_page_layout_meta_box' );

function republic_build_page_layout_meta_box( $post ){
    // Make sure the form request comes from WordPress
    wp_nonce_field( basename( __FILE__ ), 'republic_meta_box_noncepage' );
    // Retrieve the _pagepost_republic current value
    $current_republic = get_post_meta( $post->ID, '_pagepost_republic', true );
    $layout_options = array(
        'rsd' => '<img src="' . get_template_directory_uri() . '/images/right.png" alt="Right Sidebar - Default">',
        'ls'  => '<img src="' . get_template_directory_uri() . '/images/left.png" alt="Left Sidebar">',
        'lr'  => '<img src="' . get_template_directory_uri() . '/images/bothsides.png" alt="Left - Right Sidebars">',
        'fc'  => '<img src="' . get_template_directory_uri() . '/images/fullnone.png" alt="Full Content - No Sidebar">'
    );
    ?>
           <?php foreach ($layout_options as $value => $image) : ?>
                <label>
                    <input type="radio" name="republic_layoutpage" value="<?php echo esc_attr($value); ?>" <?php checked( $current_republic, $value ); ?> />
                    <?php echo $image; ?>
                </label>
            <?php endforeach; ?>
    <?php
}

/**
 * Store custom field meta box data
 *
 * @param int $post_id The post ID.
 */
function republic_save_meta_page_data( $post_id ){
    // Verify meta box nonce
    if ( !isset( $_POST['republic_meta_box_noncepage'] ) || !wp_verify_nonce( $_POST['republic_meta_box_noncepage'], basename( __FILE__ ) ) ){
        return;
    }
    // Return if autosave
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ){
        return;
    }
    // Check the user's permissions
    if ( ! current_user_can( 'edit_post', $post_id ) ){
        return;
    }
    // Store custom fields values
    if ( isset( $_POST['republic_layoutpage'] ) ) {
        update_post_meta( $post_id, '_pagepost_republic', sanitize_text_field( $_POST['republic_layoutpage'] ) );
    }
}
add_action( 'save_post', 'republic_save_meta_page_data' );
